@@ -3,7 +3,8 @@ package Test::OpenTracing::Interface;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.23.1';
+our $VERSION = '0.01';
+
 
 
 package Test::OpenTracing::Interface::Base;
@@ -34,10 +35,7 @@ has message => (
 sub this_name {
     my $self = shift;
     
-    my $this_name = defined blessed( $self->test_this ) ?
-        blessed( $self->test_this ) : $self->test_this;
-    
-    return $this_name
+    return blessed( $self->test_this ) // $self->test_this;
 }
 
 
