@@ -59,8 +59,7 @@ sub test_object { bless {}, $_[0]->test_class_name() }
 
 sub ok_message {
     my $self = shift;
-    my $test_class = shift;
-    $test_class = $self->test_class_name unless defined $test_class;
+    my $test_class = shift // $self->test_class_name;
     my $interface_name = $self->interface_name;
     return "ok 1 - $test_class->can_all_ok( '$interface_name' )"
 }
@@ -82,12 +81,11 @@ sub diag_messages {
 }
 
 
-# Since there are is a 'ClassName' type-constraint,
-# it needs to have a non-empty ISA
+# Since there are is a 'ClassName' type-constraint, it needs to have an ISA
 #
 package MyTest::Empty;
 
-our @ISA = ('MyTest');
+our @ISA;
 
 
 
